@@ -1,31 +1,28 @@
 # Oraperl Emulation Interface for Perl 5 DBD::Oracle DBI
 #
-# $Id: Oraperl.pm,v 1.36 1998/05/25 22:11:34 timbo Exp $
+# Oraperl.pm
 #
 #   Copyright (c) 1994,1995 Tim Bunce
 #
-#   You may distribute under the terms of either the GNU General Public
-#   License or the Artistic License, as specified in the Perl README file,
-#   with the exception that it cannot be placed on a CD-ROM or similar media
-#   for commercial distribution without the prior approval of the author.
+#   See the COPYRIGHT section in the Oracle.pm file for terms.
 #
 # To use this interface use one of the following invocations:
 #
 #       use Oraperl;
 # or
-#       eval 'use Oraperl; 1' || die $@ if $] >= 5;
+#       eval 'use Oraperl; 1;' || die $@ if $] >= 5;
 #
 # The second form allows oraperl scripts to be used with
 # both oraperl and perl 5.
 
 package Oraperl;
 
-require 5.002;
+require 5.004;
 
-use DBI 0.84;
+use DBI 1.22;
 use Exporter;
 
-$VERSION = substr(q$Revision: 1.36 $, 10);
+$VERSION = substr(q$Revision: 1.44 $, 10);
 
 @ISA = qw(Exporter);
 
@@ -58,7 +55,7 @@ if (!$safe) {
 $drh = DBI->install_driver('Oracle');
 if ($drh) {
     print "DBD::Oracle driver installed as $drh\n" if $debug;
-    $drh->debug($debug);
+    $drh->trace($debug);
     $drh->{CompatMode} = 1;
     $drh->{Warn}       = 0;
 }
@@ -77,7 +74,7 @@ sub _warn {
     if ($_[0] =~ /^(Bad|Duplicate) free/) {
 	return unless $ENV{PERL_DBD_DUMP} eq 'dump';
 	print STDERR "Aborting with a core dump for diagnostics (PERL_DBD_DUMP)\n";
-	dump;
+	CORE::dump;
     }
     $prev_warn ? &$prev_warn(@_) : warn @_;
 }
@@ -92,12 +89,13 @@ sub ora_login {
     my($system_id, $name, $password) = @_;
     local($Oraperl::prev_warn) = $SIG{'__WARN__'} || 0; # must be local
     local($SIG{'__WARN__'}) = sub { _warn($Oraperl::prev_warn, @_) };
-    # we still use the old style connect call with an explicit driver
-    my $dbh = DBI->connect($system_id, $name, $password, 'Oracle');
-    return $dbh;
+    return DBI->connect("dbi:Oracle:$system_id", $name, $password, {
+	PrintError => 0, AutoCommit => 0
+    });
 }
 sub ora_logoff {
     my($dbh) = @_;
+    return if !$dbh;
     local($Oraperl::prev_warn) = $SIG{'__WARN__'} || 0; # must be local
     local($SIG{'__WARN__'}) = sub { _warn($Oraperl::prev_warn, @_) };
     $dbh->disconnect();
@@ -187,9 +185,9 @@ sub ora_autocommit {
 sub ora_version {
     my($sw)  = DBI->internal;
     print "\n";
-    print "Oraperl Emulation Interface version $Oraperl::VERSION\n";
-    print "Oracle Driver $Oraperl::drh->{Version}\n";
-    print "$sw->{Attribution}, version $sw->{Version}\n\n";
+    print "Oraperl emulation interface version $Oraperl::VERSION\n";
+    print "$Oraperl::drh->{Attribution}\n";
+    print "$sw->{Attribution}\n\n";
 }
 
 
@@ -197,11 +195,8 @@ sub ora_version {
 #
 #   $ora_errno
 #   $ora_errstr
-
-# This is really internal knowledge but it saves using tie and
-# performance for ora_errno is very important.
-*Oraperl::ora_errno  = \$DBD::Oracle::err;
-*Oraperl::ora_errstr = \$DBD::Oracle::errstr;
+*Oraperl::ora_errno  = \$DBI::err;
+*Oraperl::ora_errstr = \$DBI::errstr;
 
 
 # -----------------------------------------------------------------
@@ -224,9 +219,9 @@ $Oraperl::ora_trunc = 0; 	# long trunc is error, oraperl default
 # -----------------------------------------------------------------
 #
 # Non-oraperl extensions added here to make it easy to still run
-# script using oraperl (by avoiding $csr->readblob(...))
+# script using oraperl (by avoiding $csr->blob_read(...))
 
-*ora_readblob = _func_ref('st::readblob');
+*ora_readblob = _func_ref('st::blob_read');
 
 
 1;
@@ -234,11 +229,11 @@ __END__
 
 =head1 NAME
 
-Oraperl - Perl access to Oracle databases for old oraperl scripts
+Oraperl - deprecated (Repreived for now, but Will be removed in a future release) Perl access to Oracle databases for old oraperl scripts
 
 =head1 SYNOPSIS
 
-  eval 'use Oraperl; 1' || die $@ if $] >= 5;  # ADD THIS LINE TO OLD SCRIPTS
+  eval 'use Oraperl; 1;' || die $@ if $] >= 5;  # ADD THIS LINE TO OLD SCRIPTS
 
   $lda = &ora_login($system_id, $name, $password)
   $csr = &ora_open($lda, $stmt [, $cache])
@@ -270,6 +265,13 @@ Oraperl - Perl access to Oracle databases for old oraperl scripts
 
 Oraperl is an extension to Perl which allows access to Oracle databases.
 
+The original oraperl was a Perl 4 binary with Oracle OCI compiled into it.
+The Perl 5 Oraperl module described here is distributed with L<DBD::Oracle>
+(a database driver what operates within L<DBI>) and adds an extra layer over
+L<DBI> method calls.
+The Oraperl module should only be used to allow existing Perl 4 oraperl scripts
+to run with minimal changes; any new development should use L<DBI> directly.
+
 The functions which make up this extension are described in the
 following sections. All functions return a false or undefined (in the
 Perl sense) value to indicate failure.  You do not need to understand
@@ -288,7 +290,7 @@ Oraperl;>> in each file or package. If you need to make the scripts work
 with both the perl4 oraperl and perl5 you should add add the following
 text instead:
 
-  eval 'use Oraperl; 1' || die $@ if $] >= 5;
+  eval 'use Oraperl; 1;' || die $@ if $] >= 5;
 
 =head2 Principal Functions
 
@@ -421,9 +423,9 @@ other datatypes is always considered a error.
 B<DBD:> The optional second parameter to ora_fetch is not supported.
 A DBI usage error will be generated if a second parameter is supplied.
 Use the global variable $ora_trunc instead. Also note that the
-experimental DBI readblob method can be used to retrieve a long:
+experimental DBI blob_read method can be used to retrieve a long:
 
-  $csr->readblob($field, $offset, $len [, \$dest, $destoffset]);
+  $csr->blob_read($field, $offset, $len [, \$dest, $destoffset]);
 
 If truncation occurs, $ora_errno will be set to 1406.  &ora_fetch()
 will complete successfully if truncation is permitted, otherwise it
@@ -827,7 +829,7 @@ It is quite possible, indeed probable, that some differences in
 behaviour will exist. These are probably confined to error handling.
 
 B<All> differences in behaviour which are not documented here should be
-reported to Tim.Bunce@ig.co.uk B<and> CC'd to dbi-users@fugue.com.
+reported to to dbi-users@perl.org.
 
 
 =head1 SEE ALSO
@@ -850,16 +852,25 @@ perl(1)
 
 =back
 
-=head1 AUTHORS
-
-Perl by Larry Wall <lwall@netlabs.com>.
-
-ORACLE by Oracle Corporation, California.
+=head1 AUTHOR
 
 Original Oraperl 2.4 code and documentation
 by Kevin Stock <kstock@auspex.fr>.
 
-DBI and Oraperl emulation using DBD::Oracle
-by <Tim.Bunce@ig.co.uk>
+DBI and Oraperl emulation using DBD::Oracle by Tim Bunce.
+
+=head1 MAINTAINER
+    
+As of DBD::Oracle release 1.17 in February 2006 The Pythian Group, Inc.
+(L<http://www.pythian.com>) are taking the lead in maintaining DBD::Oracle with
+my assistance and gratitude.
+
+=head1 COPYRIGHT
+
+Copyright (c) 1994-2006 Tim Bunce. Ireland.
+Copyright (c) 2006-2008 John Scoles (The Pythian Group). Canada.
+
+The DBD::Oracle module is free open source software; you can
+redistribute it and/or modify it under the same terms as Perl 5.
 
 =cut
